@@ -89,20 +89,19 @@ def plot_graph(gin, plotpath='/tmp/mygraph.png', inverty=False, ax=None, shppath
 
     for attrs in [('lon', 'lat'), ('posx', 'posy'), ('x', 'y')]:
         if attrs[0] in g.vertex_attributes():
-            xattr = 'x'; yattr = 'y'
+            xattr = attrs[0]; yattr = attrs[1]
 
-    if inverty:
-        g.vs[yattr] = (- np.array(g.vs[yattr])).tolist()
+    if inverty: g.vs[yattr] = (- np.array(g.vs[yattr])).tolist()
 
     vcoords = np.array([(x, y) for x, y in zip(g.vs[xattr], g.vs[yattr])])
     vcoords = vcoords.astype(float)
 
     ecoords = []
     for e in g.es:
-        ecoords.append([ [float(g.vs[e.source]['x']), float(g.vs[e.source]['y'])],
-                [float(g.vs[e.target]['x']), float(g.vs[e.target]['y'])], ])
+        ecoords.append([ [float(g.vs[e.source][xattr]), float(g.vs[e.source][yattr])],
+                [float(g.vs[e.target][xattr]), float(g.vs[e.target][yattr])], ])
 
     ax = plot_graph_coords(vcoords, ecoords, ax, shppath)
-    # ax.axis('off')
+    ax.axis('off')
     plt.tight_layout()
     plt.savefig(plotpath)
